Index: trunk/psphot/src/mark_psf_sources.c
===================================================================
--- trunk/psphot/src/mark_psf_sources.c	(revision 4114)
+++ trunk/psphot/src/mark_psf_sources.c	(revision 4630)
@@ -37,8 +37,8 @@
 	nSy = dSY * SY * SN;
 
 	// assign PS_SOURCE_BRIGHTSTAR to bright objects within PSF region of dparams[]
 	if ((fabs(nSx) < shapeNsigma) && (fabs(nSy) < shapeNsigma)) {
 	    if (SN > snFaint) {
-		source->type = PS_SOURCE_BRIGHTSTAR;
+		source->type = PS_SOURCE_GOODSTAR;
 	    } else {
 		source->type = PS_SOURCE_FAINTSTAR;
@@ -37,8 +37,8 @@
 	nSy = dSY * SY * SN;
 
-	// assign PS_SOURCE_BRIGHTSTAR to bright objects within PSF region of dparams[]
+	// assign PS_SOURCE_GOODSTAR to bright objects within PSF region of dparams[]
 	if ((fabs(nSx) < shapeNsigma) && (fabs(nSy) < shapeNsigma)) {
 	    if (SN > snFaint) {
